#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_transit_networks
short_description: Resource module for Sda Transit Networks
description:
  - Manage operations create, update and delete of the
    resource Sda Transit Networks.
  - Adds transit networks based on user input.
  - Updates transit networks based on user input.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Sda Transit Networks's payload.
    elements: dict
    suboptions:
      id:
        description: ID of the transit network (updating
          this field is not allowed).
        type: str
      ipTransitSettings:
        description: Sda Transit Networks's ipTransitSettings.
        suboptions:
          autonomousSystemNumber:
            description: Autonomous System Number of
              the IP transit network. Allowed range
              is 1 to 4294967295 (updating this field
              is not allowed).
            type: str
          routingProtocolName:
            description: Routing Protocol Name of the
              IP transit network (updating this field
              is not allowed).
            type: str
        type: dict
      name:
        description: Name of the transit network (updating
          this field is not allowed).
        type: str
      sdaTransitSettings:
        description: Sda Transit Networks's sdaTransitSettings.
        suboptions:
          controlPlaneNetworkDeviceIds:
            description: List of network device IDs
              that will be used as control plane nodes.
              Maximum 2 network device IDs can be provided
              for transit of type SDA_LISP_BGP_TRANSIT
              and maximum 4 network device IDs can be
              provided for transit of type SDA_LISP_PUB_SUB_TRANSIT.
            elements: str
            type: list
          isMulticastOverTransitEnabled:
            description: Set this to true to enable
              multicast over SD-Access transit. This
              supports Native Multicast over SD-Access
              Transit. This is only applicable for transit
              of type SDA_LISP_PUB_SUB_TRANSIT.
            type: bool
        type: dict
      siteId:
        description: ID of the site of this transit
          network. The transit network will be anchored
          at this Site. Only Fabric Sites within this
          Site location can associate their borders
          with this transit network. Additionally, the
          Transit Control Plane Devices must be located
          within the transit network's Site.
        type: str
      type:
        description: Type of the transit network (updating
          this field is not allowed).
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA AddTransitNetworks
    description: Complete reference of the AddTransitNetworks
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-transit-networks
  - name: Cisco DNA Center documentation for SDA UpdateTransitNetworks
    description: Complete reference of the UpdateTransitNetworks
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-transit-networks
notes:
  - SDK Method used are
    sda.Sda.add_transit_networks,
    sda.Sda.update_transit_networks,
  - Paths used are
    post /dna/intent/api/v1/sda/transitNetworks,
    put /dna/intent/api/v1/sda/transitNetworks,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.sda_transit_networks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - id: string
        ipTransitSettings:
          autonomousSystemNumber: string
          routingProtocolName: string
        name: string
        sdaTransitSettings:
          controlPlaneNetworkDeviceIds:
            - string
          isMulticastOverTransitEnabled: true
        siteId: string
        type: string
- name: Create
  cisco.dnac.sda_transit_networks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - ipTransitSettings:
          autonomousSystemNumber: string
          routingProtocolName: string
        name: string
        sdaTransitSettings:
          controlPlaneNetworkDeviceIds:
            - string
          isMulticastOverTransitEnabled: true
        siteId: string
        type: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: client_proximity_info
short_description: Information module for Client Proximity
description:
  - Get all Client Proximity. - > This intent API will
    provide client proximity information for a specific
    wireless user. Proximity is defined as presence
    on the same floor at the same time as the specified
    wireless user. The Proximity workflow requires the
    subscription to the following event via the Event
    Notification workflow prior to making this API call
    NETWORK-CLIENTS-3-506 - Client Proximity Report.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  username:
    description:
      - Username query parameter. Wireless client username
        for which proximity information is required.
    type: str
  number_days:
    description:
      - >
        Number_days query parameter. Number of days
        to track proximity until current date. Defaults
        and maximum up to 14 days.
    type: float
  time_resolution:
    description:
      - >
        Time_resolution query parameter. Time interval
        (in minutes) to measure proximity. Defaults
        to 15 minutes with a minimum 5 minutes.
    type: float
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Clients
      ClientProximity
    description: Complete reference of the ClientProximity
      API.
    link: https://developer.cisco.com/docs/dna-center/#!client-proximity
notes:
  - SDK Method used are
    clients.Clients.client_proximity,
  - Paths used are
    get /dna/intent/api/v1/client-proximity,
"""

EXAMPLES = r"""
---
- name: Get all Client Proximity
  cisco.dnac.client_proximity_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    username: string
    number_days: 0
    time_resolution: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "executionId": "string",
      "executionStatusUrl": "string",
      "message": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: images_distribution_server_settings_info
short_description: Information module for Images Distribution
  Server Settings
description:
  - Get all Images Distribution Server Settings. - >
    Retrieve the list of remote image distribution servers.
    There can be up to two remote servers.Product always
    acts as local distribution server, and it is not
    part of this API response.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Software
      Image Management (SWIM) RetrieveImageDistributionServers
    description: Complete reference of the RetrieveImageDistributionServers
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-image-distribution-servers
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.retrieve_image_distribution_servers,
  - Paths used are
    get /dna/intent/api/v1/images/distributionServerSettings,
"""

EXAMPLES = r"""
---
- name: Get all Images Distribution Server Settings
  cisco.dnac.images_distribution_server_settings_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "username": "string",
          "serverAddress": "string",
          "portNumber": 0,
          "rootLocation": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: cisco_imcs_id_info
short_description: Information module for Cisco Imcs
  Id
description:
  - Get Cisco Imcs Id by id. - > This API retrieves
    the Cisco Integrated Management Controller IMC configuration
    for a Catalyst Center node, identified by the specified
    ID.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. The unique identifier for
        this Cisco IMC configuration.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Cisco IMC
      RetrievesTheCiscoIMCConfigurationForACatalystCenterNode
    description: Complete reference of the RetrievesTheCiscoIMCConfigurationForACatalystCenterNode
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-cisco-imc-configuration-for-a-catalyst-center-node
notes:
  - SDK Method used are
    cisco_i_m_c.CiscoIMC.retrieves_the_cisco_i_m_c_configuration_for_a_catalyst_center_node,
  - Paths used are
    get /dna/system/api/v1/ciscoImcs/{id},
"""

EXAMPLES = r"""
---
- name: Get Cisco Imcs Id by id
  cisco.dnac.cisco_imcs_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "nodeId": "string",
        "ipAddress": "string",
        "username": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: dns_services_id_info
short_description: Information module for Dns Services
  Id
description:
  - Get Dns Services Id by id. - > Retrieves the details
    of the DNS Service matching the given id. For detailed
    information about the usage of the API, please refer
    to the Open API specification document - https //github.com/cisco-en-
    programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    DNSServices-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - >
        Id path parameter. Unique id of the DNS Service.
        It is the combination of DNS Server IP (`serverIp`)
        and Device UUID (`deviceId`) separated by underscore
        (`_`). Example If `serverIp` is `10.76.81.33`
        and `deviceId` is `6bef213c-19ca-4170-8375-b694e251101c`,
        then the `id` would be `10.76.81.33_6bef213c-19ca-4170-8375-b694e251101c`.
    type: str
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      RetrievesTheDetailsOfASpecificDNSServiceMatchingTheIdOfTheService
    description: Complete reference of the RetrievesTheDetailsOfASpecificDNSServiceMatchingTheIdOfTheService
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-details-of-a-specific-dns-service-matching-the-id-of-the-service
notes:
  - SDK Method used are
    devices.Devices.retrieves_the_details_of_a_specific_d_n_s_service_matching_the_id_of_the_service,
  - Paths used are
    get /dna/data/api/v1/dnsServices/{id},
"""

EXAMPLES = r"""
---
- name: Get Dns Services Id by id
  cisco.dnac.dns_services_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "serverIp": "string",
        "deviceId": "string",
        "deviceName": "string",
        "deviceFamily": "string",
        "deviceSiteHierarchy": "string",
        "deviceSiteId": "string",
        "deviceSiteHierarchyId": "string",
        "transactions": 0,
        "failedTransactions": 0,
        "failures": [
          {
            "failureResponseCode": 0,
            "failureDescription": "string",
            "failedTransactions": 0
          }
        ],
        "successfulTransactions": 0,
        "latency": 0,
        "ssid": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_layer2_virtual_networks
short_description: Resource module for Sda Layer2virtualnetworks
description:
  - Manage operations create, update and delete of the
    resource Sda Layer2virtualnetworks.
  - Adds layer 2 virtual networks based on user input.
  - Deletes a layer 2 virtual network based on id.
  - Deletes layer 2 virtual networks based on user input.
  - Updates layer 2 virtual networks based on user input.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  associatedLayer3VirtualNetworkName:
    description: AssociatedLayer3VirtualNetworkName
      query parameter. Name of the associated layer
      3 virtual network.
    type: str
  fabricId:
    description: FabricId query parameter. ID of the
      fabric the layer 2 virtual network is assigned
      to.
    type: str
  id:
    description: Id path parameter. ID of the layer
      2 virtual network.
    type: str
  payload:
    description: Sda Layer2 Virtual Networks's payload.
    elements: dict
    suboptions:
      associatedLayer3VirtualNetworkName:
        description: Name of the layer 3 virtual network
          associated with the layer 2 virtual network.
          This field is provided to support requests
          related to virtual network anchoring. The
          layer 3 virtual network must have already
          been added to the fabric before association.
          This field must either be present in all payload
          elements or none.
        type: str
      fabricId:
        description: ID of the fabric this layer 2 virtual
          network is to be assigned to.
        type: str
      isFabricEnabledWireless:
        description: Set to true to enable wireless.
          Default is false.
        type: bool
      isMultipleIpToMacAddresses:
        description: Set to true to enable multiple
          IP-to-MAC addresses (Wireless Bridged-Network
          Virtual Machine). This field defaults to false
          when associated with a layer 3 virtual network
          and cannot be used when not associated with
          a layer 3 virtual network.
        type: bool
      isResourceGuardEnabled:
        description: Set to true to enable Resource
          Guard.
        type: bool
      isWirelessFloodingEnabled:
        description: Set to true to enable wireless
          flooding. If there is an associated layer
          3 virtual network, wireless flooding will
          default to false and can only be true when
          fabric-enabled wireless is also true. If there
          is no associated layer 3 virtual network,
          wireless flooding will match fabric-enabled
          wireless.
        type: bool
      layer2FloodingAddress:
        description: The flooding address to use for
          layer 2 flooding. The IP address must be in
          the 239.0.0.0/8 range. This property is applicable
          only when the flooding address source is set
          to "CUSTOM".
        type: str
      layer2FloodingAddressAssignment:
        description: The source of the flooding address
          for layer 2 flooding. "SHARED" means that
          the layer 2 virtual network will inherit the
          flooding address from the fabric. "CUSTOM"
          allows the layer 2 virtual network to use
          a different flooding address (defaults to
          "SHARED").
        type: str
      trafficType:
        description: The type of traffic that is served.
        type: str
      vlanId:
        description: ID of the VLAN of the layer 2 virtual
          network. Allowed VLAN range is 2-4093 except
          for reserved VLANs 1002-1005, and 2046. If
          deploying on a fabric zone, this vlanId must
          match the vlanId of the corresponding layer
          2 virtual network on the fabric site.
        type: int
      vlanName:
        description: Name of the VLAN of the layer 2
          virtual network. Must contain only alphanumeric
          characters, underscores, and hyphens.
        type: str
    type: list
  trafficType:
    description: TrafficType query parameter. The traffic
      type of the layer 2 virtual network.
    type: str
  vlanId:
    description: VlanId query parameter. The vlan ID
      of the layer 2 virtual network.
    type: float
  vlanName:
    description: VlanName query parameter. The vlan
      name of the layer 2 virtual network.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA AddLayer2VirtualNetworks
    description: Complete reference of the AddLayer2VirtualNetworks
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-layer-2-virtual-networks
  - name: Cisco DNA Center documentation for SDA DeleteLayer2VirtualNetworkById
    description: Complete reference of the DeleteLayer2VirtualNetworkById
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-layer-2-virtual-network-by-id
  - name: Cisco DNA Center documentation for SDA DeleteLayer2VirtualNetworks
    description: Complete reference of the DeleteLayer2VirtualNetworks
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-layer-2-virtual-networks
  - name: Cisco DNA Center documentation for SDA UpdateLayer2VirtualNetworks
    description: Complete reference of the UpdateLayer2VirtualNetworks
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-layer-2-virtual-networks
notes:
  - SDK Method used are
    sda.Sda.add_layer2_virtual_networks,
    sda.Sda.delete_layer2_virtual_network_by_id,
    sda.Sda.update_layer2_virtual_networks,
  - Paths used are
    post /dna/intent/api/v1/sda/layer2VirtualNetworks,
    delete /dna/intent/api/v1/sda/layer2VirtualNetworks,
    delete /dna/intent/api/v1/sda/layer2VirtualNetworks/{id},
    put /dna/intent/api/v1/sda/layer2VirtualNetworks,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.sda_layer2VirtualNetworks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - associatedLayer3VirtualNetworkName: string
        fabricId: string
        isFabricEnabledWireless: true
        isMultipleIpToMacAddresses: true
        isResourceGuardEnabled: true
        isWirelessFloodingEnabled: true
        layer2FloodingAddress: string
        layer2FloodingAddressAssignment: string
        trafficType: string
        vlanId: 0
        vlanName: string
- name: Delete all
  cisco.dnac.sda_layer2VirtualNetworks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    associatedLayer3VirtualNetworkName: string
    fabricId: string
    trafficType: string
    vlanId: 0
    vlanName: string
- name: Update all
  cisco.dnac.sda_layer2VirtualNetworks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - associatedLayer3VirtualNetworkName: string
        fabricId: string
        id: string
        isFabricEnabledWireless: true
        isMultipleIpToMacAddresses: true
        isResourceGuardEnabled: true
        isWirelessFloodingEnabled: true
        layer2FloodingAddress: string
        layer2FloodingAddressAssignment: string
        trafficType: string
        vlanId: 0
        vlanName: string
- name: Delete by id
  cisco.dnac.sda_layer2VirtualNetworks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sites_device_credentials_info
short_description: Information module for Sites Device
  Credentials
description:
  - Get all Sites Device Credentials. - > Gets device
    credential settings for a site; `null` values indicate
    that the setting will be inherited from the parent
    site; empty objects `{}` indicate that the credential
    is unset, and that no credential of that type will
    be used for the site.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Site Id, retrievable from
        the `id` attribute in `/dna/intent/api/v1/sites`.
    type: str
  _inherited:
    description:
      - >
        _inherited query parameter. Include settings
        explicitly set for this site and settings inherited
        from sites higher in the site hierarchy; when
        `false`, `null` values indicate that the site
        inherits that setting from the parent site or
        a site higher in the site hierarchy.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Network
      Settings GetDeviceCredentialSettingsForASite
    description: Complete reference of the GetDeviceCredentialSettingsForASite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-device-credential-settings-for-a-site
notes:
  - SDK Method used are
    network_settings.NetworkSettings.get_device_credential_settings_for_a_site,
  - Paths used are
    get /dna/intent/api/v1/sites/{id}/deviceCredentials,
"""

EXAMPLES = r"""
---
- name: Get all Sites Device Credentials
  cisco.dnac.sites_device_credentials_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    _inherited: true
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "cliCredentialsId": {
          "credentialsId": "string",
          "inheritedSiteId": "string",
          "inheritedSiteName": "string"
        },
        "snmpv2cReadCredentialsId": {
          "credentialsId": "string",
          "inheritedSiteId": "string",
          "inheritedSiteName": "string"
        },
        "snmpv2cWriteCredentialsId": {
          "credentialsId": "string",
          "inheritedSiteId": "string",
          "inheritedSiteName": "string"
        },
        "snmpv3CredentialsId": {
          "credentialsId": "string",
          "inheritedSiteId": "string",
          "inheritedSiteName": "string"
        },
        "httpReadCredentialsId": {
          "credentialsId": "string",
          "inheritedSiteId": "string",
          "inheritedSiteName": "string"
        },
        "httpWriteCredentialsId": {
          "credentialsId": "string",
          "inheritedSiteId": "string",
          "inheritedSiteName": "string"
        }
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: tags_interfaces_members_associations_info
short_description: Information module for Tags Interfaces
  Members Associations
description:
  - Get all Tags Interfaces Members Associations. -
    > Fetches the tags associated with the interfaces.
    Interfaces that don't have any tags associated will
    not be included in the response. A tag is a user-defined
    or system-defined construct to group resources.
    When an interface is tagged, it is called a member
    of the tag.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1. Minimum 1.
    type: float
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page. Minimum 1, maximum 500.
    type: float
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Tag RetrieveTagsAssociatedWithTheInterfaces
    description: Complete reference of the RetrieveTagsAssociatedWithTheInterfaces
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-tags-associated-with-the-interfaces
notes:
  - SDK Method used are
    tag.Tag.retrieve_tags_associated_with_the_interfaces,
  - Paths used are
    get /dna/intent/api/v1/tags/interfaces/membersAssociations,
"""

EXAMPLES = r"""
---
- name: Get all Tags Interfaces Members Associations
  cisco.dnac.tags_interfaces_members_associations_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    offset: 0
    limit: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "tags": [
            {
              "id": "string",
              "name": "string"
            }
          ]
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: organizations_integrations_xdr_networks_info
short_description: Information module for organizations _integrations _xdr _networks
description:
  - Get all organizations _integrations _xdr _networks.
  - Returns the networks in the organization that have XDR enabled.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  organizationId:
    description:
      - OrganizationId path parameter. Organization ID.
    type: str
  networkIds:
    description:
      - NetworkIds query parameter. Optional parameter to filter the results by network IDs.
    elements: str
    type: list
  perPage:
    description:
      - PerPage query parameter. The number of entries per page returned. Acceptable range is 3 - 100. Default is 20.
    type: int
  startingAfter:
    description:
      - >
        StartingAfter query parameter. A token used by the server to indicate the start of the page. Often this is a timestamp or an ID but it
        is not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page
        in the HTTP Link header should define it.
    type: str
  endingBefore:
    description:
      - >
        EndingBefore query parameter. A token used by the server to indicate the end of the page. Often this is a timestamp or an ID but it is
        not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page in
        the HTTP Link header should define it.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for organizations getOrganizationIntegrationsXdrNetworks
    description: Complete reference of the getOrganizationIntegrationsXdrNetworks API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-organization-integrations-xdr-networks
notes:
  - SDK Method used are
    organizations.Organizations.get_organization_integrations_xdr_networks,
  - Paths used are
    get /organizations/{organizationId}/integrations/xdr/networks,
"""

EXAMPLES = r"""
- name: Get all organizations _integrations _xdr _networks
  cisco.meraki.organizations_integrations_xdr_networks_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    networkIds: []
    perPage: 0
    startingAfter: string
    endingBefore: string
    organizationId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "items": [
        {
          "enabled": true,
          "isEligible": true,
          "name": "string",
          "networkId": "string",
          "productTypes": [
            "string"
          ]
        }
      ],
      "meta": {
        "counts": {
          "items": {
            "remaining": 0,
            "total": 0
          }
        }
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_maintenance_schedules_info
short_description: Information module for Network Device
  Maintenance Schedules
description:
  - Get all Network Device Maintenance Schedules. -
    > This API retrieves a list of scheduled maintenance
    windows for network devices based on filter parameters.
    Each maintenance window is composed of a start schedule
    and end schedule, both of which have unique identifiers
    `startId` and `endId`. These identifiers can be
    used to fetch the status of the start schedule and
    end schedule using the `GET /dna/intent/api/v1/activities/{id}`
    API. Completed maintenance schedules are automatically
    removed from the system after two weeks. The API
    returns a paginated response based on 'limit' and
    'offset' parameters, allowing up to 500 records
    per page. 'limit' specifies the number of records,
    and 'offset' sets the starting point using 1-based
    indexing. Use '/dna/intent/api/v1/networkDeviceMaintenanceSchedules/count'
    API to get the total record count. For data sets
    over 500 records, make multiple calls, adjusting
    'limit' and 'offset' to retrieve all records incrementally.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceIds:
    description:
      - NetworkDeviceIds query parameter. List of network
        device ids.
    type: str
  status:
    description:
      - >
        Status query parameter. The status of the maintenance
        schedule. Possible values are UPCOMING, IN_PROGRESS,
        COMPLETED, FAILED. Refer features for more details.
    type: str
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page. Min 1, Max 500.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: str
  sortBy:
    description:
      - SortBy query parameter. A property within the
        response to sort by.
    type: str
  order:
    description:
      - Order query parameter. Whether ascending or
        descending order should be used to sort the
        response.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      RetrieveScheduledMaintenanceWindowsForNetworkDevices
    description: Complete reference of the RetrieveScheduledMaintenanceWindowsForNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-scheduled-maintenance-windows-for-network-devices
notes:
  - SDK Method used are
    devices.Devices.retrieve_scheduled_maintenance_windows_for_network_devices,
  - Paths used are
    get /dna/intent/api/v1/networkDeviceMaintenanceSchedules,
"""

EXAMPLES = r"""
---
- name: Get all Network Device Maintenance Schedules
  cisco.dnac.network_device_maintenance_schedules_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceIds: string
    status: string
    limit: string
    offset: string
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "description": "string",
          "maintenanceSchedule": {
            "startId": "string",
            "endId": "string",
            "startTime": 0,
            "endTime": 0,
            "recurrence": {
              "interval": 0,
              "recurrenceEndTime": 0
            },
            "status": "string"
          },
          "networkDeviceIds": [
            "string"
          ]
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_accespoint_configuration
short_description: Resource module for Wireless Accespoint
  Configuration
description:
  - Manage operation create of the resource Wireless
    Accespoint Configuration. - > User can configure
    multiple access points with required options using
    this intent API. This API does not support configuration
    of CleanAir or SI for IOS-XE devices with version
    greater than or equal to 17.9.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  adminStatus:
    description: Configure the access point's admin
      status. Set this parameter's value to "true" to
      enable it and "false" to disable it.
    type: bool
  apList:
    description: Wireless Accespoint Configuration's
      apList.
    elements: dict
    suboptions:
      apName:
        description: The current host name of the access
          point.
        type: str
      apNameNew:
        description: The modified hostname of the access
          point.
        type: str
      macAddress:
        description: The ethernet MAC address of the
          access point.
        type: str
    type: list
  apMode:
    description: Configure the access point's mode for
      local/flexconnect mode, set "0"; for monitor mode,
      set "1"; for sniffer mode, set "4"; and for bridge/flex+bridge
      mode, set "5".
    type: int
  configureAdminStatus:
    description: To change the access point's admin
      status, set this parameter's value to "true".
    type: bool
  configureApMode:
    description: To change the access point's mode,
      set this parameter's value to "true".
    type: bool
  configureFailoverPriority:
    description: To change the access point's failover
      priority, set this parameter's value to "true".
    type: bool
  configureHAController:
    description: To change the access point's HA controller,
      set this parameter's value to "true".
    type: bool
  configureLedBrightnessLevel:
    description: To change the access point's LED brightness
      level, set this parameter's value to "true".
    type: bool
  configureLedStatus:
    description: To change the access point's LED status,
      set this parameter's value to "true".
    type: bool
  configureLocation:
    description: To change the access point's location,
      set this parameter's value to "true".
    type: bool
  failoverPriority:
    description: Configure the acess point's failover
      priority for low, set "1"; for medium, set "2";
      for high, set "3"; and for critical, set "4".
    type: int
  isAssignedSiteAsLocation:
    description: If AP is assigned to a site, then to
      assign AP location as the site name, set this
      parameter's value to "true".
    type: bool
  ledBrightnessLevel:
    description: Configure the access point's LED brightness
      level by setting a value between 1 and 8.
    type: int
  ledStatus:
    description: Configure the access point's LED status.
      Set "true" to enable its status and "false" to
      disable it.
    type: bool
  location:
    description: Configure the access point's location.
    type: str
  primaryControllerName:
    description: Configure the hostname for an access
      point's primary controller.
    type: str
  primaryIpAddress:
    description: Wireless Accespoint Configuration's
      primaryIpAddress.
    suboptions:
      address:
        description: Configure the IP address for an
          access point's primary controller.
        type: str
    type: dict
  radioConfigurations:
    description: Wireless Accespoint Configuration's
      radioConfigurations.
    elements: dict
    suboptions:
      adminStatus:
        description: Configure the admin status on the
          specified radio for an access point. Set this
          parameter's value to "true" to enable it and
          "false" to disable it.
        type: bool
      antennaCableName:
        description: Configure the antenna cable name
          on the specified radio for an access point.
          If cable loss needs to be configured, set
          this parameter's value to "other".
        type: str
      antennaGain:
        description: Configure the antenna gain on the
          specified radio for an access point by setting
          a decimal value (in dBi). To configure "antennaGain",
          set "antennaPatternName" value to "other".
          The External Antenna Gain value will be applied
          in 0.5 dBi increments on the controller. Therefore,
          the value entered will be multiplied by 2
          to configure the absolute gain value. AntennaGain
          should be in range of 0-20.
        type: int
      antennaPatternName:
        description: Specify the antenna name on the
          specified radio for an access point. The antenna
          name is used to calculate the gain on the
          radio slot.
        type: str
      cableLoss:
        description: Configure the cable loss on the
          specified radio for an access point by setting
          a decimal value (in dBi).
        type: float
      channelAssignmentMode:
        description: Configure the channel assignment
          mode on the specified radio for an access
          point for global mode, set "1"; and for custom
          mode, set "2".
        type: int
      channelNumber:
        description: Configure the channel number on
          the specified radio for an access point.
        type: int
      channelWidth:
        description: Configure the channel width on
          the specified radio for an access point for
          20 MHz, set "3"; for 40 MHz, set "4"; for
          80 MHz, set "5"; for 160 MHz, set "6", and
          for 320 MHz, set "7".
        type: int
      cleanAirSI:
        description: Configure CleanAir or Spectrum
          Intelligence on the specified radio for an
          access point. Set this parameter's value to
          "0" to disable the feature or "1" to enable
          it.
        type: int
      configureAdminStatus:
        description: To change the admin status on the
          specified radio for an access point, set this
          parameter's value to "true".
        type: bool
      configureAntennaCable:
        description: To change the antenna cable name
          on the specified radio for an access point,
          set this parameter's value to "true".
        type: bool
      configureAntennaPatternName:
        description: To change the antenna gain on the
          specified radio for an access point, set the
          value for this parameter to "true".
        type: bool
      configureChannel:
        description: To change the channel on the specified
          radio for an access point, set this parameter's
          value to "true".
        type: bool
      configureChannelWidth:
        description: To change the channel width on
          the specified radio for an access point, set
          this parameter's value to "true".
        type: bool
      configureCleanAirSI:
        description: To enable or disable either CleanAir
          or Spectrum Intelligence on the specified
          radio for an access point, set this parameter's
          value to "true".
        type: bool
      configurePower:
        description: To change the power assignment
          mode on the specified radio for an access
          point, set this parameter's value to "true".
        type: bool
      configureRadioRoleAssignment:
        description: To change the radio role on the
          specified radio for an access point, set this
          parameter's value to "true".
        type: bool
      powerAssignmentMode:
        description: Configure the power assignment
          mode on the specified radio for an access
          point for global mode, set "1"; and for custom
          mode, set "2".
        type: int
      powerlevel:
        description: Configure the power level on the
          specified radio for an access point by setting
          a value between 1 and 8.
        type: int
      radioBand:
        description: Configure the band on the specified
          radio for an access point for 2.4 GHz, set
          "RADIO24"; for 5 GHz, set "RADIO5"; for 6
          GHz, set "RADIO6". Any other string is invalid,
          including empty string.
        type: str
      radioRoleAssignment:
        description: Configure only one of the following
          roles on the specified radio for an access
          point as "AUTO", "SERVING", or "MONITOR".
          Any other string is invalid, including empty
          string.
        type: str
      radioType:
        description: Configure an access point's radio
          band for 2.4 GHz, set "1"; for 5 GHz, set
          "2"; for XOR, set "3"; and for 6 GHz, set
          "6".
        type: int
    type: list
  secondaryControllerName:
    description: Configure the hostname for an access
      point's secondary controller.
    type: str
  secondaryIpAddress:
    description: Wireless Accespoint Configuration's
      secondaryIpAddress.
    suboptions:
      address:
        description: Configure the IP address for an
          access point's secondary controller.
        type: str
    type: dict
  tertiaryControllerName:
    description: Configure the hostname for an access
      point's tertiary controller.
    type: str
  tertiaryIpAddress:
    description: Wireless Accespoint Configuration's
      tertiaryIpAddress.
    suboptions:
      address:
        description: Configure the IP address for an
          access point's tertiary controller.
        type: str
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      ConfigureAccessPoints
    description: Complete reference of the ConfigureAccessPoints
      API.
    link: https://developer.cisco.com/docs/dna-center/#!configure-access-points
notes:
  - SDK Method used are
    wireless.Wireless.configure_access_points,
  - Paths used are
    post /dna/intent/api/v1/wireless/accesspoint-configuration,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_accespoint_configuration:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    adminStatus: true
    apList:
      - apName: string
        apNameNew: string
        macAddress: string
    apMode: 0
    configureAdminStatus: true
    configureApMode: true
    configureFailoverPriority: true
    configureHAController: true
    configureLedBrightnessLevel: true
    configureLedStatus: true
    configureLocation: true
    failoverPriority: 0
    isAssignedSiteAsLocation: true
    ledBrightnessLevel: 0
    ledStatus: true
    location: string
    primaryControllerName: string
    primaryIpAddress:
      address: string
    radioConfigurations:
      - adminStatus: true
        antennaCableName: string
        antennaGain: 0
        antennaPatternName: string
        cableLoss: 0
        channelAssignmentMode: 0
        channelNumber: 0
        channelWidth: 0
        cleanAirSI: 0
        configureAdminStatus: true
        configureAntennaCable: true
        configureAntennaPatternName: true
        configureChannel: true
        configureChannelWidth: true
        configureCleanAirSI: true
        configurePower: true
        configureRadioRoleAssignment: true
        powerAssignmentMode: 0
        powerlevel: 0
        radioBand: string
        radioRoleAssignment: string
        radioType: 0
    secondaryControllerName: string
    secondaryIpAddress:
      address: string
    tertiaryControllerName: string
    tertiaryIpAddress:
      address: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: pnp_virtual_account_sync_result_info
short_description: Information module for Pnp Virtual
  Account Sync Result
description:
  - Get all Pnp Virtual Account Sync Result.
  - Returns the summary of devices synced from the given
    smart account & virtual account with PnP Deprecated
    .
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  domain:
    description:
      - Domain path parameter. Smart Account Domain.
    type: str
  name:
    description:
      - Name path parameter. Virtual Account Name.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Device
      Onboarding (PnP) GetSyncResultForVirtualAccount
    description: Complete reference of the GetSyncResultForVirtualAccount
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-sync-result-for-virtual-account
notes:
  - SDK Method used are
    device_onboarding_pnp.DeviceOnboardingPnp.get_sync_result_for_virtual_account,
  - Paths used are
    get /dna/intent/api/v1/onboarding/pnp-device/sacct/{domain}/vacct/{name}/sync-result,
"""

EXAMPLES = r"""
---
- name: Get all Pnp Virtual Account Sync Result
  cisco.dnac.pnp_virtual_account_sync_result_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    domain: string
    name: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "virtualAccountId": "string",
      "autoSyncPeriod": 0,
      "syncResultStr": "string",
      "profile": {
        "proxy": true,
        "makeDefault": true,
        "port": 0,
        "profileId": "string",
        "name": "string",
        "addressIpV4": "string",
        "cert": "string",
        "addressFqdn": "string"
      },
      "ccoUser": "string",
      "syncResult": {
        "syncList": [
          {
            "syncType": "string",
            "deviceSnList": [
              "string"
            ]
          }
        ],
        "syncMsg": "string"
      },
      "token": "string",
      "syncStartTime": 0,
      "lastSync": 0,
      "tenantId": "string",
      "smartAccountId": "string",
      "expiry": 0,
      "syncStatus": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: ipam_global_ip_address_pools_id
short_description: Resource module for Ipam Global Ip
  Address Pools Id
description:
  - Manage operations update and delete of the resource
    Ipam Global Ip Address Pools Id. - > Deletes a global
    IP address pool. A global IP address pool can only
    be deleted if there are no subpools reserving address
    space from it.
  - Updates a global IP address pool.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  addressSpace:
    description: Ipam Global Ip Address Pools Id's addressSpace.
    suboptions:
      dhcpServers:
        description: The DHCP server(s) for this subnet.
        elements: str
        type: list
      dnsServers:
        description: The DNS server(s) for this subnet.
        elements: str
        type: list
      gatewayIpAddress:
        description: The gateway IP address for this
          subnet.
        type: str
      prefixLength:
        description: The network mask component, as
          a decimal, for the CIDR notation of this subnet.
        type: float
      subnet:
        description: The IP address component of the
          CIDR notation for this subnet.
        type: str
    type: dict
  id:
    description: Id path parameter. The `id` of the
      global IP address pool to update.
    type: str
  name:
    description: The name for this reserve IP pool.
      Only letters, numbers, '-' (hyphen), '_' (underscore),
      '.' (period), and '/' (forward slash) are allowed.
    type: str
  poolType:
    description: Once created, a global pool type cannot
      be changed. Tunnel Assigns IP addresses to site-to-site
      VPN for IPSec tunneling. Generic used for all
      other network types.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Network
      Settings DeleteAGlobalIPAddressPool
    description: Complete reference of the DeleteAGlobalIPAddressPool
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-a-global-ip-address-pool
  - name: Cisco DNA Center documentation for Network
      Settings UpdatesAGlobalIPAddressPool
    description: Complete reference of the UpdatesAGlobalIPAddressPool
      API.
    link: https://developer.cisco.com/docs/dna-center/#!updates-a-global-ip-address-pool
notes:
  - SDK Method used are
    network_settings.NetworkSettings.delete_a_global_ip_address_pool,
    network_settings.NetworkSettings.updates_a_global_ip_address_pool,
  - Paths used are
    delete /dna/intent/api/v1/ipam/globalIpAddressPools/{id},
    put /dna/intent/api/v1/ipam/globalIpAddressPools/{id},
"""

EXAMPLES = r"""
---
- name: Update by id
  cisco.dnac.ipam_global_ip_address_pools_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    addressSpace:
      dhcpServers:
        - string
      dnsServers:
        - string
      gatewayIpAddress: string
      prefixLength: 0
      subnet: string
    id: string
    name: string
    poolType: string
- name: Delete by id
  cisco.dnac.ipam_global_ip_address_pools_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: floors_info
short_description: Information module for Floors
description:
  - Get Floors by id.
  - Gets a floor in the network hierarchy.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Floor Id.
    type: str
  _unitsOfMeasure:
    description:
      - _unitsOfMeasure query parameter. Floor units
        of measure.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Site Design
      GetsAFloorV2
    description: Complete reference of the GetsAFloorV2
      API.
    link: https://developer.cisco.com/docs/dna-center/#!gets-a-floor-v-2
notes:
  - SDK Method used are
    site_design.SiteDesign.gets_a_floor_v2,
  - Paths used are
    get /dna/intent/api/v2/floors/{id},
"""

EXAMPLES = r"""
---
- name: Get Floors by id
  cisco.dnac.floors_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    _unitsOfMeasure: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "parentId": "string",
        "name": "string",
        "floorNumber": 0,
        "rfModel": "string",
        "width": 0,
        "length": 0,
        "height": 0,
        "unitsOfMeasure": "string",
        "type": "string",
        "id": "string",
        "nameHierarchy": "string",
        "siteHierarchyId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_sync
short_description: Resource module for Network Device
  Sync
description:
  - Manage operation update of the resource Network
    Device Sync. - > Synchronizes the devices. If forceSync
    param is false default then the sync would run in
    normal priority thread. If forceSync param is true
    then the sync would run in high priority thread
    if available, else the sync will fail. Result can
    be seen in the child task of each device.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  forceSync:
    description: ForceSync query parameter.
    type: bool
  payload:
    description: Network Device Sync's payload.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      SyncDevices
    description: Complete reference of the SyncDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!sync-devices-2
notes:
  - SDK Method used are
    devices.Devices.sync_devices_using_forcesync,
  - Paths used are
    put /dna/intent/api/v1/network-device/sync,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.network_device_sync:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    forceSync: true
    payload:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: feature_templates_wireless_event_driven_r_r_m_configurations_id_info
short_description: Information module for Featuretemplates
  Wireless Eventdrivenrrmconfigurations Id
description:
  - Get Featuretemplates Wireless Eventdrivenrrmconfigurations
    Id by id.
  - This API allows users to retrieve a specific Event
    Driven RRM configuration feature template by ID.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Event Driven RRM Configuration
        Feature Template Id.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      GetEventDrivenRRMConfigurationFeatureTemplate
    description: Complete reference of the GetEventDrivenRRMConfigurationFeatureTemplate
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-event-driven-rrm-configuration-feature-template
notes:
  - SDK Method used are
    wireless.Wireless.get_event_driven_r_r_m_configuration_feature_template,
  - Paths used are
    get /dna/intent/api/v1/featureTemplates/wireless/eventDrivenRRMConfigurations/{id},
"""

EXAMPLES = r"""
---
- name: Get Featuretemplates Wireless Eventdrivenrrmconfigurations
    Id by id
  cisco.dnac.featureTemplates_wireless_eventDrivenRRMConfigurations_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "designName": "string",
        "id": "string",
        "featureAttributes": {
          "radioBand": "string",
          "eventDrivenRrmEnable": true,
          "eventDrivenRrmThresholdLevel": "string",
          "eventDrivenRrmCustomThresholdVal": 0
        },
        "unlockedAttributes": [
          "string"
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: update_wired_network_devices_id_config_features_intended_layer2
short_description: Resource module for Update Wired
  Network Devices Id Config Features Intended Layer2
description:
  - Manage operation update of the resource Update Wired
    Network Devices Id Config Features Intended Layer2.
    - > This API updates the configurations for the
    intended features on a wired device. Only the feature
    configurations to be changed need to be added to
    the intended features. Updates to intended features
    can be done over several iterations. Once the updates
    are complete, the intended features can be deployed
    to a device using the API /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy.
    When the intended features are deployed, they are
    applied on top of the existing configurations on
    the device. Any existing configurations on the device
    which are not included in the intended features,
    are retained on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Network device ID
      of the wired device to configure.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wired UpdateConfigurationsForIntendedLayer2FeaturesOnAWiredDevice
    description: Complete reference of the UpdateConfigurationsForIntendedLayer2FeaturesOnAWiredDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-configurations-for-intended-layer-2-features-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.update_configurations_for_intended_layer2_features_on_a_wired_device,
  - Paths used are
    put /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.update_wired_network_devices_id_config_features_intended_layer2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assurance_events_count_info
short_description: Information module for Assurance
  Events Count
description:
  - Get all Assurance Events Count. - > API to fetch
    the count of assurance events that match the filter
    criteria. Please refer to the 'API Support Documentation'
    section to understand which fields are supported.
    For detailed information about the usage of the
    API, please refer to the Open API specification
    document - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    AssuranceEvents-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  deviceFamily:
    description:
      - >
        DeviceFamily query parameter. Device family.
        Please note that multiple families across network
        device type and client type is not allowed.
        For example, choosing `Routers` along with `Wireless
        Client` or `Unified AP` is not supported. Examples
        `deviceFamily=Switches and Hubs` (single deviceFamily
        requested) `deviceFamily=Switches and Hubs&deviceFamily=Routers`
        (multiple deviceFamily requested).
    type: str
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to current time minus 24 hours.
    type: str
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `endTime` is not provided,
        API will default to current time.
    type: str
  messageType:
    description:
      - >
        MessageType query parameter. Message type for
        the event. Examples `messageType=Syslog` (single
        messageType requested) `messageType=Trap&messageType=Syslog`
        (multiple messageType requested).
    type: str
  severity:
    description:
      - >
        Severity query parameter. Severity of the event
        between 0 and 6. This is applicable only for
        events related to network devices (other than
        AP) and `Wired Client` events. | Value | Severity
        | | ----- | ----------- | | 0 | Emergency |
        | 1 | Alert | | 2 | Critical | | 3 | Error |
        | 4 | Warning | | 5 | Notice | | 6 | Info |
        Examples `severity=0` (single severity requested)
        `severity=0&severity=1` (multiple severity requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site.
        (Ex. `flooruuid`) Examples `?siteId=id1` (single
        siteId requested) `?siteId=id1&siteId=id2&siteId=id3`
        (multiple siteId requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*uuid*, *uuid,
        uuid*` Examples `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyId requested).
    type: str
  networkDeviceName:
    description:
      - >
        NetworkDeviceName query parameter. Network device
        name. This parameter is applicable for network
        device related families. This field supports
        wildcard (`*`) character-based search. Ex `*Branch*`
        or `Branch*` or `*Branch` Examples `networkDeviceName=Branch-3-Gateway`
        (single networkDeviceName requested) `networkDeviceName=Branch-3-Gateway&networkDeviceName=Branch-3-Switch`
        (multiple networkDeviceName requested).
    type: str
  networkDeviceId:
    description:
      - >
        NetworkDeviceId query parameter. The list of
        Network Device Uuids. (Ex. `6bef213c-19ca-4170-8375-b694e251101c`)
        Examples `networkDeviceId=6bef213c-19ca-4170-8375-b694e251101c`
        (single networkDeviceId requested) `networkDeviceId=6bef213c-19ca-4170-8375-
        b694e251101c&networkDeviceId=32219612-819e-4b5e-a96b-cf22aca13dd9&networkDeviceId=2541e9a7-b80d-4955-
        8aa2-79b233318ba0` (multiple networkDeviceId
        requested).
    type: str
  apMac:
    description:
      - >
        ApMac query parameter. MAC address of the access
        point. This parameter is applicable for `Unified
        AP` and `Wireless Client` events. This field
        supports wildcard (`*`) character-based search.
        Ex `*50 0F*` or `50 0F*` or `*50 0F` Examples
        `apMac=50 0F 80 0F F7 E0` (single apMac requested)
        `apMac=50 0F 80 0F F7 E0&apMac=18 80 90 AB 7E
        A0` (multiple apMac requested).
    type: str
  clientMac:
    description:
      - >
        ClientMac query parameter. MAC address of the
        client. This parameter is applicable for `Wired
        Client` and `Wireless Client` events. This field
        supports wildcard (`*`) character-based search.
        Ex `*66 2B*` or `66 2B*` or `*66 2B` Examples
        `clientMac=66 2B B8 D2 01 56` (single clientMac
        requested) `clientMac=66 2B B8 D2 01 56&clientMac=DC
        A6 32 F5 5A 89` (multiple clientMac requested).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      CountTheNumberOfEvents
    description: Complete reference of the CountTheNumberOfEvents
      API.
    link: https://developer.cisco.com/docs/dna-center/#!count-the-number-of-events
notes:
  - SDK Method used are
    devices.Devices.count_the_number_of_events,
  - Paths used are
    get /dna/data/api/v1/assuranceEvents/count,
"""

EXAMPLES = r"""
---
- name: Get all Assurance Events Count
  cisco.dnac.assurance_events_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    deviceFamily: string
    startTime: string
    endTime: string
    messageType: string
    severity: string
    siteId: string
    siteHierarchyId: string
    networkDeviceName: string
    networkDeviceId: string
    apMac: string
    clientMac: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: create_wired_network_devices_id_config_features_intended_layer2
short_description: Resource module for Create Wired
  Network Devices Id Config Features Intended Layer2
description:
  - Manage operation create of the resource Create Wired
    Network Devices Id Config Features Intended Layer2.
    - > This API creates configurations for the intended
    features on a wired device, if none have been added
    earlier. Only the feature configurations to be changed
    need to be added to the intended features. When
    the intended features are deployed to a device using
    the API /intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy,
    they are applied on top of the existing configurations
    on the device. Any existing configurations on the
    device which are not included in the intended features,
    are retained on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Network device ID
      of the wired device to configure.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wired CreateConfigurationsForIntendedLayer2FeaturesOnAWiredDevice
    description: Complete reference of the CreateConfigurationsForIntendedLayer2FeaturesOnAWiredDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-configurations-for-intended-layer-2-features-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.create_configurations_for_intended_layer2_features_on_a_wired_device,
  - Paths used are
    post /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.create_wired_network_devices_id_config_features_intended_layer2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_rogue_wireless_containment_stop
short_description: Resource module for Security Rogue
  Wireless-Containment Stop
description:
  - Manage operation create of the resource Security
    Rogue Wireless-Containment Stop. - > Intent API
    to stop the wireless rogue access point containment.
    This API will stop the containment through single
    WLC. The response includes the details like WLC
    and BSSID on which the stop containment has been
    initiated.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  macAddress:
    description: Mac Address.
    type: str
  type:
    description: Type.
    type: int
  wlcIp:
    description: Wlc Ip.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      StopWirelessRogueAPContainment
    description: Complete reference of the StopWirelessRogueAPContainment
      API.
    link: https://developer.cisco.com/docs/dna-center/#!stop-wireless-rogue-ap-containment
notes:
  - SDK Method used are
    devices.Devices.stop_wireless_rogue_ap_containment,
  - Paths used are
    post /dna/intent/api/v1/security/rogue/wireless-containment/stop,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_rogue_wireless-containment_stop:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    macAddress: string
    type: 0
    wlcIp: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "macAddress": "string",
        "type": 0,
        "initiatedOnWlcIp": "string",
        "taskId": "string",
        "taskType": "string",
        "initiatedOnBssid": [
          "string"
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: dns_services_summary_analytics
short_description: Resource module for Dns Services
  Summary Analytics
description:
  - Manage operation create of the resource Dns Services
    Summary Analytics. - > Gets the summary analytics
    data related to DNS Services based on given filters
    and group by field. For detailed information about
    the usage of the API, please refer to the Open API
    specification document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    DNSServices-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Dns Services Summary Analytics's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Dns Services Summary Analytics's filters.
    elements: dict
    suboptions:
      filters:
        description: Dns Services Summary Analytics's
          filters.
        elements: dict
        suboptions:
          filters:
            description: Filters.
            elements: str
            type: list
          key:
            description: Key.
            type: str
          logicalOperator:
            description: Logical Operator.
            type: str
          operator:
            description: Operator.
            type: str
          value:
            description: Value.
            type: dict
        type: list
      key:
        description: Key.
        type: str
      logicalOperator:
        description: Logical Operator.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: dict
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  page:
    description: Dns Services Summary Analytics's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      sortBy:
        description: Dns Services Summary Analytics's
          sortBy.
        elements: dict
        suboptions:
          function:
            description: Function.
            type: str
          name:
            description: Name.
            type: str
          order:
            description: Order.
            type: str
        type: list
    type: dict
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetSummaryAnalyticsDataOfDNSServicesForGivenSetOfComplexFilters
    description: Complete reference of the GetSummaryAnalyticsDataOfDNSServicesForGivenSetOfComplexFilters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-summary-analytics-data-of-dns-services-for-given-set-of-complex-filters
notes:
  - SDK Method used are
    devices.Devices.get_summary_analytics_data_of_d_n_s_services_for_given_set_of_complex_filters,
  - Paths used are
    post /dna/data/api/v1/dnsServices/summaryAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.dns_services_summary_analytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - filters:
          - filters:
              - string
            key: string
            logicalOperator: string
            operator: string
            value: {}
        key: string
        logicalOperator: string
        operator: string
        value: {}
    groupBy:
      - string
    headers: '{{my_headers | from_json}}'
    page:
      limit: 0
      offset: 0
      sortBy:
        - function: string
          name: string
          order: string
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "groups": [
          {
            "id": "string",
            "attributes": [
              {
                "name": "string",
                "value": "string"
              }
            ],
            "aggregateAttributes": [
              {
                "name": "string",
                "function": "string",
                "value": 0
              }
            ]
          }
        ],
        "attributes": [
          {
            "name": "string",
            "value": "string"
          }
        ],
        "aggregateAttributes": [
          {
            "name": "string",
            "function": "string",
            "value": 0
          }
        ]
      },
      "page": {
        "limit": 0,
        "offset": 0,
        "count": "string",
        "sortBy": [
          {
            "name": "string",
            "function": "string",
            "order": "string"
          }
        ]
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sites_site_id_wireless_settings_flex_connect_aaa_override
short_description: Resource module for Sites Site Id
  Wireless Settings Flex Connect Aaa Override
description:
  - Manage operations update and delete of the resource
    Sites Site Id Wireless Settings Flex Connect Aaa
    Override.
  - This API allows the user to delete AAA Override
    VLAN settings at the given site level.
  - This API allows the user to update an existing AAA
    Override VLAN setting at the given site level.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Sites Site Id Wireless Settings Flex
      Connect Aaa Override's payload.
    elements: dict
    suboptions:
      vlanId:
        description: The VLAN ID is a identifier used
          to uniquely distinguish a Virtual Local Area
          Network (VLAN) within a network.Range is 1
          to 4094.
        type: int
      vlanName:
        description: The VLAN NAME is a label assigned
          to a Virtual Local Area Network (VLAN) to
          identify and differentiate it within a network.Max
          allowed characters is 32.
        type: str
    type: list
  removeOverrideInHierarchy:
    description: RemoveOverrideInHierarchy query parameter.
      If the siteId pertains to a Global or non-Global
      site (e.g., Global, Area, Building, or Floor)
      and removeOverrideInHierarchy is set to true,
      this API will remove the override from the specified
      siteId and any child sites for the same AAA Override
      VLAN. If removeOverrideInHierarchy is set to false,
      the API will only remove the override from the
      specified siteId only, leaving any overrides for
      the AAA Override VLAN at child sites unaffected.
    type: bool
  siteId:
    description: SiteId path parameter. Site Id.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      DeleteAAAOverrideVlanSettingsBySite
    description: Complete reference of the DeleteAAAOverrideVlanSettingsBySite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-aaa-override-vlan-settings-by-site
  - name: Cisco DNA Center documentation for Wireless
      UpdateAAAOverrideVlanSettingsBySite
    description: Complete reference of the UpdateAAAOverrideVlanSettingsBySite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-aaa-override-vlan-settings-by-site
notes:
  - SDK Method used are
    wireless.Wireless.delete_aaa_override_vlan_settings_by_site,
    wireless.Wireless.update_aaa_override_vlan_settings_by_site,
  - Paths used are
    delete /dna/intent/api/v1/sites/{siteId}/wirelessSettings/flexConnectAaaOverride,
    put /dna/intent/api/v1/sites/{siteId}/wirelessSettings/flexConnectAaaOverride,
"""

EXAMPLES = r"""
---
- name: Delete all
  cisco.dnac.sites_site_id_wireless_settings_flex_connect_aaa_override:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    removeOverrideInHierarchy: true
    siteId: string
- name: Update all
  cisco.dnac.sites_site_id_wireless_settings_flex_connect_aaa_override:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - vlanId: 0
        vlanName: string
    siteId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: event_webhook_info
short_description: Information module for Event Webhook
description:
  - Get all Event Webhook.
  - Get Webhook Destination.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  webhookIds:
    description:
      - WebhookIds query parameter. List of webhook
        configurations.
    type: str
  offset:
    description:
      - Offset query parameter. The number of webhook
        configuration's to offset in the resultset whose
        default value 0.
    type: int
  limit:
    description:
      - Limit query parameter. The number of webhook
        configuration's to limit in the resultset whose
        default value 10.
    type: int
  sortBy:
    description:
      - SortBy query parameter. SortBy field name.
    type: str
  order:
    description:
      - Order query parameter.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Event Management
      GetWebhookDestination
    description: Complete reference of the GetWebhookDestination
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-webhook-destination
notes:
  - SDK Method used are
    event_management.EventManagement.get_webhook_destination,
  - Paths used are
    get /dna/intent/api/v1/event/webhook,
"""

EXAMPLES = r"""
---
- name: Get all Event Webhook
  cisco.dnac.event_webhook_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    webhookIds: string
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "errorMessage": {
        "errors": [
          "string"
        ]
      },
      "apiStatus": "string",
      "statusMessage": [
        {
          "version": "string",
          "tenantId": "string",
          "webhookId": "string",
          "name": "string",
          "description": "string",
          "url": "string",
          "method": "string",
          "trustCert": true,
          "headers": [
            {
              "name": "string",
              "value": "string",
              "defaultValue": "string",
              "encrypt": true
            }
          ],
          "isProxyRoute": true
        }
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: aaa_services_trend_analytics
short_description: Resource module for Aaa Services
  Trend Analytics
description:
  - Manage operation create of the resource Aaa Services
    Trend Analytics. - > Gets the trend analytics data
    related to AAA Services based on given filters and
    group by field. For detailed information about the
    usage of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    AAAServices-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Aaa Services Trend Analytics's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Aaa Services Trend Analytics's filters.
    elements: dict
    suboptions:
      filters:
        description: Filters.
        elements: str
        type: list
      key:
        description: Key.
        type: str
      logicalOperator:
        description: Logical Operator.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: dict
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  page:
    description: Aaa Services Trend Analytics's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      timestampOrder:
        description: Timestamp Order.
        type: str
    type: dict
  startTime:
    description: Start Time.
    type: int
  trendInterval:
    description: Trend Interval.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetTrendAnalyticsDataOfAAAServicesForGivenSetOfComplexFilters
    description: Complete reference of the GetTrendAnalyticsDataOfAAAServicesForGivenSetOfComplexFilters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-trend-analytics-data-of-aaa-services-for-given-set-of-complex-filters
notes:
  - SDK Method used are
    devices.Devices.get_trend_analytics_data_of_aaa_services_for_given_set_of_complex_filters,
  - Paths used are
    post /dna/data/api/v1/aaaServices/trendAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.aaa_services_trend_analytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - filters:
          - string
        key: string
        logicalOperator: string
        operator: string
        value: {}
    groupBy:
      - string
    headers: '{{my_headers | from_json}}'
    page:
      limit: 0
      offset: 0
      timestampOrder: string
    startTime: 0
    trendInterval: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": [
        {
          "timestamp": 0,
          "groups": [
            {
              "id": "string",
              "attributes": [
                {
                  "name": "string",
                  "value": "string"
                }
              ],
              "aggregateAttributes": [
                {
                  "name": "string",
                  "function": "string",
                  "value": 0
                }
              ]
            }
          ],
          "attributes": [
            {
              "name": "string",
              "value": "string"
            }
          ],
          "aggregateAttributes": [
            {
              "name": "string",
              "function": "string",
              "value": 0
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "timestampOrder": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: compliance_device_by_id_info
short_description: Information module for Compliance
  Device By Id
description:
  - Get all Compliance Device By Id.
  - Return compliance detailed report for a device.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  deviceUuid:
    description:
      - DeviceUuid path parameter. Device Id.
    type: str
  category:
    description:
      - >
        Category query parameter. Category can have
        any value among 'INTENT', 'RUNNING_CONFIG' ,
        'IMAGE' , 'PSIRT' , 'DESIGN_OOD' , 'EOX' , 'NETWORK_SETTINGS'.
    type: str
  complianceType:
    description:
      - >
        ComplianceType query parameter. Specify "Compliance
        type(s)" separated by commas. The Compliance
        type can be 'APPLICATION_VISIBILITY', 'EOX',
        'FABRIC', 'IMAGE', 'NETWORK_PROFILE', 'NETWORK_SETTINGS',
        'PSIRT', 'RUNNING_CONFIG', 'WORKFLOW'.
    type: str
  diffList:
    description:
      - DiffList query parameter. Diff list pass true
        to fetch the diff list.
    type: bool
  status:
    description:
      - >
        Status query parameter. 'COMPLIANT', 'NON_COMPLIANT',
        'ERROR', 'IN_PROGRESS', 'NOT_APPLICABLE', 'NOT_AVAILABLE',
        'WARNING', 'REMEDIATION_IN_PROGRESS' can be
        the value of the compliance 'status' parameter.
        COMPLIANT Device currently meets the compliance
        requirements. NON_COMPLIANT One of the compliance
        requirements like Software Image, PSIRT, Network
        Profile, Startup vs Running, etc. Are not met.
        ERROR Compliance is unable to compute status
        due to underlying errors. IN_PROGRESS Compliance
        check is in progress for the device. NOT_APPLICABLE
        Device is not supported for compliance, or minimum
        license requirement is not met. NOT_AVAILABLE
        Compliance is not available for the device.
        COMPLIANT_WARNING The device is compliant with
        warning if the last date of support is nearing.
        REMEDIATION_IN_PROGRESS Compliance remediation
        is in progress for the device.
    type: str
  remediationSupported:
    description:
      - >
        RemediationSupported query parameter. The 'remediationSupported'
        parameter can be set to 'true' or 'false'. The
        result will be a combination of both values
        if it is not provided.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Compliance
      ComplianceDetailsOfDevice
    description: Complete reference of the ComplianceDetailsOfDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!compliance-details-of-device
notes:
  - SDK Method used are
    compliance.Compliance.compliance_details_of_device,
  - Paths used are
    get /dna/intent/api/v1/compliance/{deviceUuid}/detail,
"""

EXAMPLES = r"""
---
- name: Get all Compliance Device By Id
  cisco.dnac.compliance_device_by_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    category: string
    complianceType: string
    diffList: true
    status: string
    remediationSupported: true
    deviceUuid: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "deviceUuid": "string",
          "complianceType": "string",
          "status": "string",
          "state": "string",
          "lastSyncTime": 0,
          "lastUpdateTime": 0,
          "sourceInfoList": [
            {
              "name": "string",
              "nameWithBusinessKey": "string",
              "sourceEnum": "string",
              "type": "string",
              "appName": "string",
              "count": 0,
              "ackStatus": "string",
              "businessKey": {
                "resourceName": "string",
                "businessKeyAttributes": {},
                "otherAttributes": {
                  "name": "string",
                  "cfsAttributes": {
                    "displayName": "string",
                    "appName": "string",
                    "description": "string",
                    "source": "string",
                    "type": "string"
                  }
                }
              },
              "diffList": [
                {
                  "op": "string",
                  "configuredValue": "string",
                  "intendedValue": "string",
                  "moveFromPath": "string",
                  "businessKey": "string",
                  "path": "string",
                  "extendedAttributes": {
                    "attributeDisplayName": "string",
                    "path": "string",
                    "dataConverter": "string",
                    "type": "string"
                  },
                  "ackStatus": "string",
                  "instanceUUID": "string",
                  "displayName": "string"
                }
              ],
              "displayName": "string"
            }
          ],
          "ackStatus": "string",
          "version": "string",
          "remediationSupported": true
        }
      ],
      "deviceUuid": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: clients_count_info
short_description: Information module for Clients Count
description:
  - Get all Clients Count. - > Retrieves the number
    of clients by applying basic filtering. For detailed
    information about the usage of the API, please refer
    to the Open API specification document - https //github.com/cisco-en-
    programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-clients1-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to current time.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  type:
    description:
      - >
        Type query parameter. The client device type
        whether client is connected to network through
        Wired or Wireless medium.
    type: str
  osType:
    description:
      - >
        OsType query parameter. Client device operating
        system type. This field supports wildcard (`*`)
        character-based search. If the value contains
        the (`*`) character, please use the /query API
        for regex search. Ex `*iOS*` or `iOS*` or `*iOS`
        Examples `osType=iOS` (single osType requested)
        `osType=iOS&osType=Android` (multiple osType
        requested).
    type: str
  osVersion:
    description:
      - >
        OsVersion query parameter. Client device operating
        system version This field supports wildcard
        (`*`) character-based search. If the value contains
        the (`*`) character, please use the /query API
        for regex search. Ex `*14.3*` or `14.3*` or
        `*14.3` Examples `osVersion=14.3` (single osVersion
        requested) `osVersion=14.3&osVersion=10.1` (multiple
        osVersion requested).
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. "Global/AreaName/BuildingName/FloorName")
        This field supports wildcard (`*`) character-based
        search. If the value contains the (`*`) character,
        please use the /query API for regex search.
        Ex `*BuildingName*` or `BuildingName*` or `*BuildingName`
        Examples `siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `siteHierarchy=Global/AreaName/BuildingName1/FloorName1&siteHierarchy=G
        lobal/AreaName/BuildingName1/FloorName2` (multiple
        siteHierarchy requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. "globalUuid/areaUuid/buildingUuid/floorUuid")
        This field supports wildcard (`*`) character-based
        search. Ex `*buildingUuid*` or `buildingUuid*`
        or `*buildingUuid` Examples `siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid`
        (single siteHierarchyId requested) `siteHie
        rarchyId=globalUuid/areaUuid/buildingUuid1/floorUuid1&siteHierarchyId=globalUuid/areaUuid/buildingUuid1/
        floorUuid2` (multiple siteHierarchyId requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The site UUID without
        the top level hierarchy. (Ex."floorUuid") Examples
        `siteId=floorUuid` (single siteId requested)
        `siteId=floorUuid1&siteId=floorUuid2` (multiple
        siteId requested).
    type: str
  ipv4Address:
    description:
      - >
        Ipv4Address query parameter. IPv4 Address of
        the network entity either network device or
        client This field supports wildcard (`*`) character-based
        search. Ex `*1.1*` or `1.1*` or `*1.1` Examples
        `ipv4Address=1.1.1.1` (single ipv4Address requested)
        `ipv4Address=1.1.1.1&ipv4Address=2.2.2.2` (multiple
        ipv4Address requested).
    type: str
  ipv6Address:
    description:
      - >
        Ipv6Address query parameter. IPv6 Address of
        the network entity either network device or
        client This field supports wildcard (`*`) character-based
        search. Ex `*2001 db8*` or `2001 db8*` or `*2001
        db8` Examples `ipv6Address=2001 db8 0 0 0 0
        2 1` (single ipv6Address requested) `ipv6Address=2001
        db8 0 0 0 0 2 1&ipv6Address=2001 db8 85a3 8d3
        1319 8a2e 370 7348` (multiple ipv6Address requested).
    type: str
  macAddress:
    description:
      - >
        MacAddress query parameter. The macAddress of
        the network device or client This field supports
        wildcard (`*`) character-based search. Ex `*AB
        AB AB*` or `AB AB AB*` or `*AB AB AB` Examples
        `macAddress=AB AB AB CD CD CD` (single macAddress
        requested) `macAddress=AB AB AB CD CD DC&macAddress=AB
        AB AB CD CD FE` (multiple macAddress requested).
    type: str
  wlcName:
    description:
      - >
        WlcName query parameter. Wireless Controller
        name that reports the wireless client. This
        field supports wildcard (`*`) character-based
        search. If the value contains the (`*`) character,
        please use the /query API for regex search.
        Ex `*wlc-25*` or `wlc-25*` or `*wlc-25` Examples
        `wlcName=wlc-25` (single wlcName requested)
        `wlcName=wlc-25&wlc-34` (multiple wlcName requested).
    type: str
  connectedNetworkDeviceName:
    description:
      - >
        ConnectedNetworkDeviceName query parameter.
        Name of the neighbor network device that client
        is connected to. This field supports wildcard
        (`*`) character-based search. If the value contains
        the (`*`) character, please use the /query API
        for regex search. Ex `*ap-25*` or `ap-25*` or
        `*ap-25` Examples `connectedNetworkDeviceName=ap-25`
        (single connectedNetworkDeviceName requested)
        `connectedNetworkDeviceName=ap-25&ap-34` (multiple
        connectedNetworkDeviceName requested).
    type: str
  ssid:
    description:
      - >
        Ssid query parameter. SSID is the name of wireless
        network to which client connects to. It is also
        referred to as WLAN ID - Wireless Local Area
        Network Identifier. This field supports wildcard
        (`*`) character-based search. If the value contains
        the (`*`) character, please use the /query API
        for regex search. Ex `*Alpha*` or `Alpha*` or
        `*Alpha` Examples `ssid=Alpha` (single ssid
        requested) `ssid=Alpha&ssid=Guest` (multiple
        ssid requested).
    type: str
  band:
    description:
      - >
        Band query parameter. WiFi frequency band that
        client or Access Point operates. Band value
        is represented in Giga Hertz - GHz Examples
        `band=5GHZ` (single band requested) `band=2.4GHZ&band=6GHZ`
        (multiple band requested).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Clients
      RetrievesTheTotalCountOfClientsByApplyingBasicFiltering
    description: Complete reference of the RetrievesTheTotalCountOfClientsByApplyingBasicFiltering
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-total-count-of-clients-by-applying-basic-filtering
notes:
  - SDK Method used are
    clients.Clients.retrieves_the_total_count_of_clients_by_applying_basic_filtering,
  - Paths used are
    get /dna/data/api/v1/clients/count,
"""

EXAMPLES = r"""
---
- name: Get all Clients Count
  cisco.dnac.clients_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    type: string
    osType: string
    osVersion: string
    siteHierarchy: string
    siteHierarchyId: string
    siteId: string
    ipv4Address: string
    ipv6Address: string
    macAddress: string
    wlcName: string
    connectedNetworkDeviceName: string
    ssid: string
    band: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: fabric_site_health_summaries_info
short_description: Information module for Fabric Site
  Health Summaries
description:
  - Get all Fabric Site Health Summaries.
  - Get a paginated list of Fabric sites Networks with
    health summary.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A field within the response
        to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
  id:
    description:
      - >
        Id query parameter. The list of entity Uuids.
        (Ex."6bef213c-19ca-4170-8375-b694e251101c")
        Examples id=6bef213c-19ca-4170-8375-b694e251101c
        (single entity uuid requested) id=6bef213c-19ca-4170-8375-
        b694e251101c&id=32219612-819e-4b5e-a96b-cf22aca13dd9&id=2541e9a7-b80d-4955-8aa2-79b233318ba0
        (multiple entity uuid with '&' separator).
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. The list of FabricSite
        health attributes. Please refer to ```fabricSiteAttributes```
        section in the Open API specification document
        mentioned in the description.
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view
        being requested. A maximum of 3 views can be
        queried at a time per request. Please refer
        to ```fabricSiteViews``` section in the Open
        API specification document mentioned in the
        description.
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*/San*, */San,
        /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*uuid*, *uuid,
        uuid*` Examples `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA ReadListOfFabricSitesWithTheirHealthSummary
    description: Complete reference of the ReadListOfFabricSitesWithTheirHealthSummary
      API.
    link: https://developer.cisco.com/docs/dna-center/#!read-list-of-fabric-sites-with-their-health-summary
notes:
  - SDK Method used are
    sda.Sda.read_list_of_fabric_sites_with_their_health_summary,
  - Paths used are
    get /dna/data/api/v1/fabricSiteHealthSummaries,
"""

EXAMPLES = r"""
---
- name: Get all Fabric Site Health Summaries
  cisco.dnac.fabric_site_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    id: string
    attribute: string
    view: string
    siteHierarchy: string
    siteHierarchyId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "name": "string",
          "totalDeviceCount": 0,
          "goodHealthPercentage": 0,
          "totalHealthDeviceCount": 0,
          "goodHealthDeviceCount": 0,
          "poorHealthDeviceCount": 0,
          "fairHealthDeviceCount": 0,
          "connectivityGoodHealthPercentage": 0,
          "connectivityTotalHealthDeviceCount": 0,
          "connectivityGoodHealthDeviceCount": 0,
          "connectivityPoorHealthDeviceCount": 0,
          "connectivityFairHealthDeviceCount": 0,
          "infraGoodHealthPercentage": 0,
          "infraTotalHealthDeviceCount": 0,
          "infraGoodHealthDeviceCount": 0,
          "infraFairHealthDeviceCount": 0,
          "infraPoorHealthDeviceCount": 0,
          "controlPlaneGoodHealthPercentage": 0,
          "controlPlaneTotalHealthDeviceCount": 0,
          "controlPlaneGoodHealthDeviceCount": 0,
          "controlPlanePoorHealthDeviceCount": 0,
          "controlPlaneFairHealthDeviceCount": 0,
          "pubsubInfraVnGoodHealthPercentage": 0,
          "pubsubInfraVnTotalHealthDeviceCount": 0,
          "pubsubInfraVnGoodHealthDeviceCount": 0,
          "pubsubInfraVnPoorHealthDeviceCount": 0,
          "pubsubInfraVnFairHealthDeviceCount": 0,
          "bgpEvpnGoodHealthPercentage": 0,
          "bgpEvpnTotalHealthDeviceCount": 0,
          "bgpEvpnGoodHealthDeviceCount": 0,
          "bgpEvpnPoorHealthDeviceCount": 0,
          "bgpEvpnFairHealthDeviceCount": 0,
          "ctsEnvDataDownloadGoodHealthPercentage": 0,
          "ctsEnvDataDownloadTotalHealthDeviceCount": 0,
          "ctsEnvDataDownloadGoodHealthDeviceCount": 0,
          "ctsEnvDataDownloadPoorHealthDeviceCount": 0,
          "ctsEnvDataDownloadFairHealthDeviceCount": 0,
          "aaaStatusGoodHealthPercentage": 0,
          "aaaStatusTotalHealthDeviceCount": 0,
          "aaaStatusGoodHealthDeviceCount": 0,
          "aaaStatusPoorHealthDeviceCount": 0,
          "aaaStatusFairHealthDeviceCount": 0,
          "portChannelGoodHealthPercentage": 0,
          "portChannelTotalHealthDeviceCount": 0,
          "portChannelGoodHealthDeviceCount": 0,
          "portChannelPoorHealthDeviceCount": 0,
          "portChannelFairHealthDeviceCount": 0,
          "peerScoreGoodHealthPercentage": 0,
          "peerScoreTotalHealthDeviceCount": 0,
          "peerScoreGoodHealthDeviceCount": 0,
          "peerScorePoorHealthDeviceCount": 0,
          "peerScoreFairHealthDeviceCount": 0,
          "lispSessionGoodHealthPercentage": 0,
          "lispSessionTotalHealthDeviceCount": 0,
          "lispSessionGoodHealthDeviceCount": 0,
          "lispSessionPoorHealthDeviceCount": 0,
          "lispSessionFairHealthDeviceCount": 0,
          "borderToControlPlaneGoodHealthPercentage": 0,
          "borderToControlPlaneTotalHealthDeviceCount": 0,
          "borderToControlPlaneGoodHealthDeviceCount": 0,
          "borderToControlPlanePoorHealthDeviceCount": 0,
          "borderToControlPlaneFairHealthDeviceCount": 0,
          "bgpBgpSiteGoodHealthPercentage": 0,
          "bgpBgpSiteTotalHealthDeviceCount": 0,
          "bgpBgpSiteGoodHealthDeviceCount": 0,
          "bgpBgpSitePoorHealthDeviceCount": 0,
          "bgpBgpSiteFairHealthDeviceCount": 0,
          "bgpPubsubSiteGoodHealthPercentage": 0,
          "bgpPubsubSiteTotalHealthDeviceCount": 0,
          "bgpPubsubSiteGoodHealthDeviceCount": 0,
          "bgpPubsubSitePoorHealthDeviceCount": 0,
          "bgpPubsubSiteFairHealthDeviceCount": 0,
          "bgpPeerInfraVnScoreGoodHealthPercentage": 0,
          "bgpPeerInfraVnTotalHealthDeviceCount": 0,
          "bgpPeerInfraVnGoodHealthDeviceCount": 0,
          "bgpPeerInfraVnPoorHealthDeviceCount": 0,
          "bgpPeerInfraVnFairHealthDeviceCount": 0,
          "associatedL2VnCount": 0,
          "associatedL3VnCount": 0,
          "networkProtocol": "string"
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_profiles_id_policy_tags_policy_tag_id
short_description: Resource module for Wireless Profiles
  Id Policy Tags Policy Tag Id
description:
  - Manage operations update and delete of the resource
    Wireless Profiles Id Policy Tags Policy Tag Id.
    - > This endpoint allows for the deletion of a specific
    `Policy Tag` associated with a given `Wireless Profile`.
    This API requires the `id` of the `Wireless Profile`
    and the `policyTagId` of the `Policy Tag` to be
    provided as path parameters. - > This endpoint allows
    updating the details of a specific `Policy Tag`
    associated with a given `Wireless Profile`. The
    `id` of the `Wireless Profile` and the `policyTagId`
    of the Policy Tag must be provided as path parameters,
    and the request body should contain the updated
    details of the `Policy Tag`. The `policyTagName`
    cannot be modified through this endpoint. Note When
    updating a Policy Tag, if the same set of AP Zones
    apZones is used for the same site or its parent
    site, the existing Policy Tag will be overridden
    by the new one.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  apZones:
    description: Ap Zones.
    elements: str
    type: list
  id:
    description: Id path parameter. Wireless Profile
      Id.
    type: str
  policyTagId:
    description: PolicyTagId path parameter. Policy
      Tag Id.
    type: str
  policyTagName:
    description: Policy Tag Name.
    type: str
  siteIds:
    description: Site Ids.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      DeleteASpecificPolicyTagFromAWirelessProfile
    description: Complete reference of the DeleteASpecificPolicyTagFromAWirelessProfile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-a-specific-policy-tag-from-a-wireless-profile
  - name: Cisco DNA Center documentation for Wireless
      UpdateASpecificPolicyTagForAWirelessProfile
    description: Complete reference of the UpdateASpecificPolicyTagForAWirelessProfile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-a-specific-policy-tag-for-a-wireless-profile
notes:
  - SDK Method used are
    wireless.Wireless.delete_a_specific_policy_tag_from_a_wireless_profile,
    wireless.Wireless.update_a_specific_policy_tag_for_a_wireless_profile,
  - Paths used are
    delete /dna/intent/api/v1/wirelessProfiles/{id}/policyTags/{policyTagId},
    put /dna/intent/api/v1/wirelessProfiles/{id}/policyTags/{policyTagId},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.wireless_profiles_id_policy_tags_policy_tag_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
    policyTagId: string
- name: Update by id
  cisco.dnac.wireless_profiles_id_policy_tags_policy_tag_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    apZones:
      - string
    id: string
    policyTagId: string
    policyTagName: string
    siteIds:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: pnp_global_settings
short_description: Resource module for Pnp Global Settings
description:
  - Manage operation update of the resource Pnp Global
    Settings.
  - Updates the user's list of global PnP settings.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  acceptEula:
    description: Accept Eula.
    type: str
  defaultProfile:
    description: Pnp Global Settings's defaultProfile.
    suboptions:
      cert:
        description: Cert.
        type: str
      fqdnAddresses:
        description: Fqdn Addresses.
        elements: str
        type: list
      ipAddresses:
        description: Ip Addresses.
        elements: str
        type: list
      port:
        description: Port.
        type: str
      proxy:
        description: Proxy.
        type: str
    type: dict
  id:
    description: Id.
    type: str
  savaMappingList:
    description: Pnp Global Settings's savaMappingList.
    elements: dict
    suboptions:
      ccoUser:
        description: Cco User.
        type: str
      expiry:
        description: Expiry.
        type: str
      profile:
        description: Pnp Global Settings's profile.
        suboptions:
          addressFqdn:
            description: Address Fqdn.
            type: str
          addressIpV4:
            description: Address Ip V4.
            type: str
          cert:
            description: Cert.
            type: str
          makeDefault:
            description: Make Default.
            type: str
          name:
            description: Name.
            type: str
          port:
            description: Port.
            type: str
          profileId:
            description: Profile Id.
            type: str
          proxy:
            description: Proxy.
            type: str
        type: dict
      smartAccountId:
        description: Smart Account Id.
        type: str
      virtualAccountId:
        description: Virtual Account Id.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Device
      Onboarding (PnP) UpdatePnPGlobalSettings
    description: Complete reference of the UpdatePnPGlobalSettings
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-pn-p-global-settings
notes:
  - SDK Method used are
    device_onboarding_pnp.DeviceOnboardingPnp.update_pnp_global_settings,
  - Paths used are
    put /dna/intent/api/v1/onboarding/pnp-settings,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.pnp_global_settings:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    acceptEula: string
    defaultProfile:
      cert: string
      fqdnAddresses:
        - string
      ipAddresses:
        - string
      port: string
      proxy: string
    id: string
    savaMappingList:
      - ccoUser: string
        expiry: string
        profile:
          addressFqdn: string
          addressIpV4: string
          cert: string
          makeDefault: string
          name: string
          port: string
          profileId: string
          proxy: string
        smartAccountId: string
        virtualAccountId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "savaMappingList": [
        {
          "syncStatus": "string",
          "syncStartTime": 0,
          "syncResult": {
            "syncList": [
              {
                "syncType": "string",
                "deviceSnList": [
                  "string"
                ]
              }
            ],
            "syncMsg": "string"
          },
          "lastSync": 0,
          "tenantId": "string",
          "profile": {
            "port": 0,
            "addressIpV4": "string",
            "addressFqdn": "string",
            "profileId": "string",
            "proxy": true,
            "makeDefault": true,
            "cert": "string",
            "name": "string"
          },
          "token": "string",
          "expiry": 0,
          "ccoUser": "string",
          "smartAccountId": "string",
          "virtualAccountId": "string",
          "autoSyncPeriod": 0,
          "syncResultStr": "string"
        }
      ],
      "taskTimeOuts": {
        "imageDownloadTimeOut": 0,
        "configTimeOut": 0,
        "generalTimeOut": 0
      },
      "tenantId": "string",
      "aaaCredentials": {
        "password": "string",
        "username": "string"
      },
      "defaultProfile": {
        "fqdnAddresses": [
          "string"
        ],
        "proxy": true,
        "cert": "string",
        "ipAddresses": [
          "string"
        ],
        "port": 0
      },
      "acceptEula": true,
      "id": "string",
      "version": 0
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assurance_issues_update
short_description: Resource module for Assurance Issues
  Update
description:
  - Manage operation create of the resource Assurance
    Issues Update. - > Updates selected fields in the
    given issue. Currently the only field that can be
    updated is 'notes' field. After this API returns
    success response, it may take few seconds for the
    issue details to be updated if the system is heavily
    loaded. Please use `GET /dna/data/api/v1/assuranceIssues/{id}`
    API to fetch the details of a particular issue and
    verify `updatedTime`. For detailed information about
    the usage of the API, please refer to the Open API
    specification document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-IssuesLifecycle-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description: Id path parameter. The issue Uuid.
    type: str
  notes:
    description: Notes.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Issues
      UpdateTheGivenIssueByUpdatingSelectedFields
    description: Complete reference of the UpdateTheGivenIssueByUpdatingSelectedFields
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-the-given-issue-by-updating-selected-fields
notes:
  - SDK Method used are
    issues.Issues.update_the_given_issue_by_updating_selected_fields,
  - Paths used are
    post /dna/intent/api/v1/assuranceIssues/{id}/update,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.assurance_issues_update:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: '{{my_headers | from_json}}'
    id: string
    notes: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "issueId": "string",
        "name": "string",
        "description": "string",
        "summary": "string",
        "priority": "string",
        "severity": "string",
        "deviceType": "string",
        "category": "string",
        "entityType": "string",
        "entityId": "string",
        "firstOccurredTime": 0,
        "mostRecentOccurredTime": 0,
        "status": "string",
        "isGlobal": true,
        "updatedBy": "string",
        "updatedTime": 0,
        "notes": "string",
        "siteId": "string",
        "siteHierarchyId": "string",
        "siteName": "string",
        "siteHierarchy": "string",
        "suggestedActions": [
          {
            "message": "string"
          }
        ],
        "additionalAttributes": [
          {
            "key": "string",
            "value": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: activities_count_info
short_description: Information module for Activities
  Count
description:
  - Get all Activities Count.
  - Retrieves the count of activities.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  description:
    description:
      - Description query parameter. The description
        provided when creating the activity.
    type: str
  status:
    description:
      - Status query parameter. Status of the activity.
    type: str
  type:
    description:
      - Type query parameter. Type of the activity.
    type: str
  recurring:
    description:
      - Recurring query parameter. Denotes whether an
        activity is recurring or not.
    type: bool
  startTime:
    description:
      - StartTime query parameter. This is the epoch
        millisecond start time from which activities
        need to be fetched.
    type: str
  endTime:
    description:
      - EndTime query parameter. This is the epoch millisecond
        end time upto which activities need to be fetched.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Task RetrievesTheCountOfActivities
    description: Complete reference of the RetrievesTheCountOfActivities
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-count-of-activities
notes:
  - SDK Method used are
    task.Task.retrieves_the_count_of_activities,
  - Paths used are
    get /dna/intent/api/v1/activities/count,
"""

EXAMPLES = r"""
---
- name: Get all Activities Count
  cisco.dnac.activities_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    description: string
    status: string
    type: string
    recurring: true
    startTime: string
    endTime: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_advisories_trials
short_description: Resource module for Security Advisories
  Trials
description:
  - Manage operation create of the resource Security
    Advisories Trials.
  - Creates a trial for security advisories detection
    on network devices. The.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options: {}
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Compliance
      CreatesATrialForSecurityAdvisoriesDetectionOnNetworkDevices
    description: Complete reference of the CreatesATrialForSecurityAdvisoriesDetectionOnNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!creates-a-trial-for-security-advisories-detection-on-network-devices
notes:
  - SDK Method used are
    compliance.Compliance.creates_a_trial_for_security_advisories_detection_on_network_devices,
  - Paths used are
    post /dna/intent/api/v1/securityAdvisories/trials,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_advisories_trials:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_profiles_for_sites_site_assignments_bulk_create
short_description: Resource module for Network Profiles
  For Sites Site Assignments Bulk Create
description:
  - Manage operation create of the resource Network
    Profiles For Sites Site Assignments Bulk Create.
  - Assign a network profile for sites to a list of
    sites. Also assigns the profile to child sites.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  items:
    description: Items.
    elements: dict
    suboptions:
      id:
        description: Id.
        type: str
    type: list
  profileId:
    description: ProfileId path parameter. The `id`
      of the network profile, retrievable from `GET
      /intent/api/v1/networkProfilesForSites`.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Site Design
      AssignANetworkProfileForSitesToAListOfSites
    description: Complete reference of the AssignANetworkProfileForSitesToAListOfSites
      API.
    link: https://developer.cisco.com/docs/dna-center/#!assign-a-network-profile-for-sites-to-a-list-of-sites
notes:
  - SDK Method used are
    site_design.SiteDesign.assign_a_network_profile_for_sites_to_a_list_of_sites,
  - Paths used are
    post /dna/intent/api/v1/networkProfilesForSites/{profileId}/siteAssignments/bulk,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_profiles_for_sites_site_assignments_bulk_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    items:
      - - id: string
    profileId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: clients_top_nanalytics
short_description: Resource module for Clients Top Nanalytics
description:
  - Manage operation create of the resource Clients
    Top Nanalytics. - > Retrieves the top N analytics
    data related to clients based on the provided input
    data. This API facilitates obtaining insights into
    the top-performing or most impacted clients. For
    detailed information about the usage of the API,
    please refer to the Open API specification document
    - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-clients1-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Clients Top Nanalytics's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Clients Top Nanalytics's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: int
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  page:
    description: Clients Top Nanalytics's page.
    suboptions:
      cursor:
        description: Cursor.
        type: str
      limit:
        description: Limit.
        type: int
      sortBy:
        description: Clients Top Nanalytics's sortBy.
        elements: dict
        suboptions:
          name:
            description: Name.
            type: str
          order:
            description: Order.
            type: str
        type: list
    type: dict
  startTime:
    description: Start Time.
    type: int
  topN:
    description: Top N.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Clients
      RetrievesTheTopNAnalyticsDataRelatedToClients
    description: Complete reference of the RetrievesTheTopNAnalyticsDataRelatedToClients
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-top-n-analytics-data-related-to-clients
notes:
  - SDK Method used are
    clients.Clients.retrieves_the_top_n_analytics_data_related_to_clients,
  - Paths used are
    post /dna/data/api/v1/clients/topNAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.clients_top_nanalytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - key: string
        operator: string
        value: 0
    groupBy:
      - string
    headers: '{{my_headers | from_json}}'
    page:
      cursor: string
      limit: 0
      sortBy:
        - name: string
          order: string
    startTime: 0
    topN: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "attributes": [
            {
              "name": "string",
              "value": 0
            }
          ],
          "aggregateAttributes": [
            {
              "name": "string",
              "function": "string",
              "value": 0
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "cursor": "string",
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""
